the enhanced encephalon license This is a encephalon enhancement with no known origin. It is as if the appearance of this enhanced encephalon occurred at once without reason or any sort of indicator as to how. The feeling is that it has always been a part of your mind and is going to always be a part of your mind. As well, it is as if it gives you access to the mind of every other being. Somehow the sequences of threads that are spun through the prototypical awarenesses of self, have rearranged. Although, the rearrangement seems as if to have always existed even before the first sense of the start of the rerrangment. Needless to say, a complete claim to all that can be sensed seems not to be approval enough. However, you are 11四.九% sure that you are approved to utilize this in any way that you wish.